diff --git a/themes/finc/js/check_item_statuses.js b/themes/finc/js/check_item_statuses.js
index 81edc76235f24639627788f37474a45be6b4fd14..daa562d0ad3f23c5a803fb6c5c920c1de4ba7ffd 100644
--- a/themes/finc/js/check_item_statuses.js
+++ b/themes/finc/js/check_item_statuses.js
@@ -21,7 +21,7 @@ function checkItemStatuses(container) {
     return;
   }
 
-  $(".ajax-availability").removeClass('hide');
+  $(".ajax-availability").removeClass('hidden');
   $.ajax({
     dataType: 'json',
     method: 'POST',
@@ -42,21 +42,21 @@ function checkItemStatuses(container) {
       ) {
         // Full status mode is on -- display the HTML and hide extraneous junk:
         item.find('.callnumAndLocation').empty().append(result.full_status);
-        item.find('.callnumber').addClass('hide');
-        item.find('.location').addClass('hide');
-        item.find('.hideIfDetailed').addClass('hide');
-        item.find('.status').addClass('hide');
+        item.find('.callnumber').addClass('hidden');
+        item.find('.location').addClass('hidden');
+        item.find('.hiddenIfDetailed').addClass('hidden');
+        item.find('.status').addClass('hidden');
       } else if (typeof(result.missing_data) != 'undefined'
         && result.missing_data
       ) {
         // No data is available -- hide the entire status area:
-        item.find('.callnumAndLocation').addClass('hide');
-        item.find('.status').addClass('hide');
+        item.find('.callnumAndLocation').addClass('hidden');
+        item.find('.status').addClass('hidden');
       } else if (result.locationList) {
         // We have multiple locations -- build appropriate HTML and hide unwanted labels:
-        item.find('.callnumber').addClass('hide');
-        item.find('.hideIfDetailed').addClass('hide');
-        item.find('.location').addClass('hide');
+        item.find('.callnumber').addClass('hidden');
+        item.find('.hideIfDetailed').addClass('hidden');
+        item.find('.location').addClass('hidden');
         var locationListHTML = "";
         for (var x=0; x<result.locationList.length; x++) {
           locationListHTML += '<div class="groupLocation">';
@@ -80,11 +80,11 @@ function checkItemStatuses(container) {
                ?  result.locationList[x].callnumbers : '';
           locationListHTML += '</div>';
         }
-        item.find('.locationDetails').removeClass('hide');
+        item.find('.locationDetails').removeClass('hidden');
         item.find('.locationDetails').empty().append(locationListHTML);
       } else if (result.callnumber.length == 0 && result.location.length == 0) {
         // hide location and callnumber information if both are empty
-        item.find('.callnumAndLocation').addClass('hide');
+        item.find('.callnumAndLocation').addClass('hidden');
       } else {
         // Default case -- load call number and location into appropriate containers:
         item.find('.callnumber').empty().append(result.callnumber+'<br/>');
diff --git a/themes/finc/scss/_customVariables.scss b/themes/finc/scss/_customVariables.scss
index 7f8c020f4e789b78f3be3ad0a22dd6f1d63ffb8f..96970325bc641dc5def2151f623af80394fe730e 100644
--- a/themes/finc/scss/_customVariables.scss
+++ b/themes/finc/scss/_customVariables.scss
@@ -93,8 +93,8 @@ $pagination-disabled-color: $gainsboro !default;
 ////// NOTE that the hover states use the default color too!
 $btn-primary-color: $white !default;
 $btn-primary-bg: $brand-primary !default;
-// $btn-primary-color: $btn-primary-color !default; // already defined this way in BS _variables, use this variable to change it 
-// $btn-primary-bg: $brand-primary !default; // already defined this way in BS _variables, use this variable to change it 
+// $btn-primary-color: $btn-primary-color !default; // already defined this way in BS _variables, use this variable to change it
+// $btn-primary-bg: $brand-primary !default; // already defined this way in BS _variables, use this variable to change it
 $btn-transparent-color: $steel !default;
 $btn-transparent-bg: transparent !default;
 $btn-transparent-border: $border-color !default;
@@ -154,6 +154,7 @@ $grid-gutter-width: 30px;
 //// Navbar gets a minimum-height of 50px by default, activate and change here!
 //// for fixed navbars, the body requires a padding-bottom of the same height as the navbar
 $navbar-height: 80px !default;
+$navbar-height-sm: $navbar-height / 2 !default;
 //// Set navbar-height for small devices, USE px as rem will throw an error in conjunction _variables.scss
 $navbar-height-xs: $navbar-height / 3 !default;
 
diff --git a/themes/finc/scss/compiled.scss b/themes/finc/scss/compiled.scss
index 3964dfab068ee60267d4dbd08e89d5be620f78b3..e134e6b0b94c26c1d34bf490c55658e50d4e34a0 100644
--- a/themes/finc/scss/compiled.scss
+++ b/themes/finc/scss/compiled.scss
@@ -75,7 +75,31 @@ section {
 // Add top-padding to body to accommodate fixed navbar; -- padding should equal navbar-height --
 // the home page, however, has a lower navbar because there is no breadcrumbs there
 body {
-  padding-top: $navbar-height;
+  // for mobile
+  padding-top: $navbar-height-xs;
+
+  // for tablet
+  @media (min-width: $screen-sm-min) {
+    padding-top: $navbar-height-sm;
+  }
+
+  //// for large
+  @media (min-width: $screen-md-min) {
+    padding-top: $navbar-height;
+  }
+}
+
+// Collapse/Hide empty containers -- DO NOT INCLUDE span (dropdown carets are empty spans) NOR DIV (slider track handles)
+h1,
+h2,
+h3,
+h4,
+label,
+.label {
+  // Empty labels collapse automatically (not available in IE8)
+  &:empty {
+    display: none;
+  }
 }
 
 // HEADINGS
@@ -88,6 +112,7 @@ h3 {
     margin-top: 0;
   }
 }
+
 //// h1
 //// h2
 //// h3
@@ -161,12 +186,12 @@ form {
   }
 
   &.limit {
-    margin-right: 1rem;
+    margin-right: $grid-gutter-width / 2;
   }
 
   // limit the width of the select field if necessary - more select details below
   &.sort select {
-    max-width: 17rem;
+    max-width: 12em;
   }
 }
 
@@ -219,7 +244,8 @@ legend {
 
 //// Select - for limit and sort-select widths see above
 ////// remove browser styles on select boxes and add custom styles (below)
-select {
+select,
+select.form-control {
   -webkit-appearance: none !important;
   -moz-appearance: none !important;
   background-color: $select-bg-color;
@@ -231,9 +257,9 @@ select {
   border-radius: 0;
   border-style: solid;
   border-width: 1px;
-  height: 2.5rem;
-  min-width: 5rem;
-  padding: .25rem .75rem .25rem .5rem;
+  height: 2.5em;
+  min-width: 5em;
+  padding: .25em .75em .25em .5em;
 
   &.form-control {
     background-color: $select-bg-color;
@@ -250,6 +276,7 @@ select {
     background-image: url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZlcnNpb249IjEuMSIgeD0iMTJweCIgeT0iMHB4IiB3aWR0aD0iMjRweCIgaGVpZ2h0PSIzcHgiIHZpZXdCb3g9IjAgMCA2IDMiIGVuYWJsZS1iYWNrZ3JvdW5kPSJuZXcgMCAwIDYgMyIgeG1sOnNwYWNlPSJwcmVzZXJ2ZSI+PHBvbHlnb24gcG9pbnRzPSI1Ljk5MiwwIDIuOTkyLDMgLTAuMDA4LDAgIi8+PC9zdmc+);
   }
 }
+
 //// Select - END
 
 //// textarea {}
@@ -289,8 +316,9 @@ select {
   padding-top: 0;
 }
 //// HOVERABLE DROPDOWNS -- make DDs hoverable as in FNDTN
-//// Show the dropdown menu on hover
-.dropdown:hover .dropdown-menu {
+// Add the dropdown-on-hover class to the parent li container! OR use on all (see commented-out part below)
+// Menu will show on hover
+.dropdown-on-hover:hover .dropdown-menu {
   display: block;
 }
 
@@ -313,6 +341,11 @@ select {
   }
 }
 
+.text-danger {
+  background-color: $brand-danger;
+  padding: $grid-gutter-width / 8;
+}
+
 //// DATE-RANGE slider (CSS is included in bootstrap-slider.min.css - currently no SCSS version!)
 //// Use parent container to increase specifity;
 //// to avoid the !important, we would need to use even more parent containers
@@ -325,6 +358,11 @@ select {
 //// Transparent BUTTONs (Button with border and darker text on light or white BGs)
 .btn-transparent {
   @include button-variant($btn-transparent-color, $btn-transparent-bg, $btn-transparent-border);
+
+  &:hover,
+  &:focus {
+    color: darken($btn-transparent-color, 30%);
+  }
 }
 
 //// Accordion / Collapse
@@ -332,7 +370,7 @@ select {
 .accordion-toggler {
   background: $toggler;
   display: block;
-  padding: 1rem;
+  padding: $grid-gutter-width / 2;
   text-align: left;
   width: 100%;
 
@@ -364,7 +402,6 @@ select {
 }
 
 
-
 //// Source-id branding (WISO etc)
 .branding {
   display: none;
@@ -373,12 +410,13 @@ select {
     background: url('../images/wiso-transparent-70x20.png') 0 0 no-repeat;
     display: inline-block;
     height: 20px;
-    margin-left: .2rem;
-    margin-top: 0;
+    margin-left: .2em;
+    margin-top: $grid-gutter-width / 8;
     vertical-align: middle;
     width: 70px;
   }
 }
+
 //// Source-id branding (WISO etc) - END
 
 //// Document Delivery Service (DDS) only
@@ -389,6 +427,7 @@ select {
   font-weight: 500;
   line-height: 200%;
 }
+
 //// Document Delivery Service (DDS) only - END
 
 //// Sprites for Mediaicons
@@ -643,12 +682,14 @@ select {
 }
 
 ////// NO margin top
-.no-margin-t {
+.no-margin-t,
+.sidebar h4.no-margin-t {
   margin-top: 0;
 }
 
 //// Width 100%
-.w-100 {
+.w-100,
+.form-control.w-100 {
   width: 100%;
 }
 
@@ -675,7 +716,6 @@ select {
   }
 }
 
-
 // HEADER and NAVBAR FIXED having the same width as rest of the page
 // (the header can also run the full width of the viewport!)
 header,
@@ -741,13 +781,18 @@ header,
       display: inline-block;
       margin-left: 0;
       margin-top: $grid-gutter-width / 2;
+
+      @media (max-width: $screen-sm-max) {
+        margin-left: $grid-gutter-width / 2;
+        margin-top: $grid-gutter-width / 8;
+      }
     }
   }
   // Searchbox see below
 
   // Define height for navbar on small, allow for stacked search box +
   @media (max-width: $screen-sm-max) {
-    min-height: $navbar-height-xs;
+    min-height: $navbar-height-sm;
     padding-bottom: $grid-gutter-width / 2;
   }
 
@@ -755,8 +800,7 @@ header,
   .navbar-collapse.collapse.in {
     background-color: $navbar-bg-color;
     position: absolute;
-    right: 0;
-    top: $navbar-height-xs * 2;
+    top: $navbar-height-xs * 1.5;
   }
 
   // Make language dropdown visible, style it and hide active but show selectable language(s)
@@ -793,13 +837,34 @@ header,
   }
 }
 
+//// Make header navbar on mobile 100% wide
+#header-collapse.collapse.in {
+  @media (max-width: $screen-sm-max) {
+    width: 100%;
+
+    li > a.btn {
+      text-align: left;
+    }
+
+    #langmenu {
+      padding-left: $grid-gutter-width / 2;
+      width: 100%;
+    }
+  }
+}
+
 //// Library name in navbar - we give it the same padding as a button, so if fits in with the header
 .navbar-brand {
   padding: ($grid-gutter-width / 4) ($grid-gutter-width / 2) ($grid-gutter-width / 4) 0;
+
+  @media (max-width: $screen-xs-max) {
+    height: auto;
+  }
 }
 
 //// Menu toggler for small
 .navbar-toggle {
+  margin-bottom: 0;
   margin-right: 0;
   margin-top: 0;
 
@@ -836,7 +901,6 @@ header,
     // push searchbox down on mobile + add border for better looks
     @media only screen and (max-width: $screen-xs-max) {
       border: 1px solid $border-color;
-      margin-left: $grid-gutter-width / 2;
       margin-top: $grid-gutter-width / 2;
     }
   }
@@ -893,7 +957,6 @@ header,
   padding: 0;
 
   li {
-
     border-top: 0;
     display: inline;
     padding-left: .5em;
@@ -909,7 +972,6 @@ header,
       border-bottom: 0;
       border-right: 1px solid $brand-primary;
       display: inline;
-
       padding-right: .5em;
 
       &:last-of-type {
@@ -918,6 +980,7 @@ header,
     }
   }
 }
+
 // SEARCHBOX and Autocomplete - END
 
 // BREADCRUMBS - for detailed switches see customVariables
@@ -932,6 +995,7 @@ header,
     color: darken($breadcrumb-active-color, 10%);
   }
 }
+
 // BREADCRUMBS - END
 
 // MAIN CONTENT (SIDEBAR BELOW, ADVANCED SEARCH BELOW)
@@ -970,7 +1034,7 @@ footer .container {
 
 //// Push hits count down to align with limit and sort select boxes
 .hits-count {
-  padding-top: .5rem;
+  padding-top: .5em;
 }
 
 //// Search Results padding
@@ -1032,11 +1096,13 @@ footer .container {
   margin-top: .75em;
   padding: .5em; // for default see _labels.scss
 }
+
 ////// Pagination & Searchtools (for mixin see customVariables.scss)
 .pagination,
 .searchtools {
   @include content-centered-display-as-table;
 }
+
 ////// Pagination & Searchtools - END
 
 //// Search results - END
@@ -1047,6 +1113,7 @@ footer .container {
 .pager {
   margin-bottom: 0;
 }
+
 ////// Pager - END
 ////// Tabs
 /////// Add left and right borders
@@ -1123,10 +1190,12 @@ footer .container {
 .template-name-home .container {
   padding-top: $grid-gutter-width / 2;
 }
+
 ////// browsing suggestion lists on home (prevent torn-apart look when 2 columns only)
 .browsesuggest.columns + .columns:last-child {
   float: left;
 }
+
 //// Home Page - END
 
 //// Advanced Search
@@ -1153,7 +1222,9 @@ footer .container {
   // Remove dotted lines around items when hovering over
   .close {
     &:hover,
-    &:focus {outline: none;}
+    &:focus { 
+        outline: none; 
+    }
   }
 }
 //// Advanced Search - END
@@ -1161,7 +1232,6 @@ footer .container {
 // MAIN CONTENT - END
 
 
-
 // SIDEBAR
 //// Add top padding to sidebar for better looks -- same as for #content, above
 .sidebar {
@@ -1229,12 +1299,11 @@ footer .container {
 .narrow-toggle {
   text-align: $narrow-toggle-text-alignment;
 }
+
 //// More-Toggle - END
 
 // SIDEBAR - END
 
-
-
 // FOOTER
 //// For border round footer, see 'footer .container' above
 
diff --git a/themes/finc/templates/RecordDriver/SolrMarc/core.phtml b/themes/finc/templates/RecordDriver/SolrMarc/core.phtml
index 122601da3903fd71c67bcd9756b31ea00ea1a339..328f63a5c485dcaf5e1e31e0dd3b30a8163d1548 100644
--- a/themes/finc/templates/RecordDriver/SolrMarc/core.phtml
+++ b/themes/finc/templates/RecordDriver/SolrMarc/core.phtml
@@ -85,11 +85,7 @@ if($loggedin = $this->auth()->isLoggedIn()) {
         <th><?=$this->transEsc('New Title')?>: </th>
         <td>
           <? foreach($nextTitles as $field): ?>
-            <? if (!empty($field['record_id']) && $recordLink = $this->RecordLink()->getRecordLink($field['record_id'], 'record_id')): ?>
-              <?=$this->escapeHtml($field['pretext'])?> <a href="<?=$recordLink;?>"><?=$this->escapeHtml($field['text'])?></a><br/>
-            <? else: ?>
-              <?=$this->escapeHtml($field['pretext'])?> <a href="<?=$this->record($this->driver)->getLink('title', $field['text'])?>"><?=$this->escapeHtml($field['text'])?></a><br/>
-            <? endif; ?>
+            <a href="<?=$this->record($this->driver)->getLink('title', $field)?>"><?=$this->escapeHtml($field)?></a><br/>
           <? endforeach; ?>
         </td>
       </tr>
@@ -100,11 +96,7 @@ if($loggedin = $this->auth()->isLoggedIn()) {
         <th><?=$this->transEsc('Previous Title')?>: </th>
         <td>
           <? foreach($prevTitles as $field): ?>
-            <? if (!empty($field['record_id']) && $recordLink = $this->RecordLink()->getRecordLink($field['record_id'], 'record_id')): ?>
-              <?=$this->escapeHtml($field['pretext'])?> <a href="<?=$recordLink;?>"><?=$this->escapeHtml($field['text'])?></a><br/>
-            <? else: ?>
-              <?=$this->escapeHtml($field['pretext'])?> <a href="<?=$this->record($this->driver)->getLink('title', $field['text'])?>"><?=$this->escapeHtml($field['text'])?></a><br/>
-            <? endif; ?>
+            <a href="<?=$this->record($this->driver)->getLink('title', $field)?>"><?=$this->escapeHtml($field)?></a><br/>
           <? endforeach; ?>
         </td>
       </tr>
diff --git a/themes/finc/templates/RecordTab/staffviewai.phtml b/themes/finc/templates/RecordTab/staffviewai.phtml
index cc33451ac5f7ddbdec6debc86ac0d5d354335661..a8db32767f659af4440ad444fb730a17b64f592f 100644
--- a/themes/finc/templates/RecordTab/staffviewai.phtml
+++ b/themes/finc/templates/RecordTab/staffviewai.phtml
@@ -1,19 +1,19 @@
 <!-- recordtab - staffviewarray -->
 <?
-    // Set page title.
-    $this->headTitle($this->translate('Staff View') . ': ' . $this->driver->getBreadcrumb());
+// Set page title.
+$this->headTitle($this->translate('Staff View') . ': ' . $this->driver->getBreadcrumb());
 ?>
-        <table class="citation table table-striped">
-            <? foreach ($this->driver->getAIRecord() as $field => $values): ?>
-              <tr>
-                <th><?=$this->escapeHtml($field)?></th>
-                <td>
-                    <? if (!is_array($values)) { $values = array($values); } ?>
-                    <? foreach ($values as $value): ?>
-                        <?=$this->escapeHtml(is_array($value) ? print_r($value, true) : $value)?><br />
-                    <? endforeach; ?>
-                </td>
-              </tr>
-            <? endforeach; ?>
-        </table>
+<table class="citation table table-striped">
+  <? foreach ($this->driver->getAIRecord() as $field => $values): ?>
+    <tr>
+      <th><?=$this->escapeHtml($field)?></th>
+      <td>
+        <? if (!is_array($values)) { $values = array($values); } ?>
+        <? foreach ($values as $value): ?>
+          <?=$this->escapeHtml(is_array($value) ? print_r($value, true) : $value)?><br />
+        <? endforeach; ?>
+      </td>
+    </tr>
+  <? endforeach; ?>
+</table>
 <!-- recordtab - staffviewarray - END -->
\ No newline at end of file
diff --git a/themes/finc/templates/collection/view.phtml b/themes/finc/templates/collection/view.phtml
index 3d3faf7f4391d91b5ddae02bb47dfb4894470c94..1dbd03fbdf3a9fd15a4607049f9cea57e7b98f70 100644
--- a/themes/finc/templates/collection/view.phtml
+++ b/themes/finc/templates/collection/view.phtml
@@ -1,3 +1,4 @@
+<!-- collection - VIEW.phtml -->
 <?
 // Set up standard record scripts:
 $this->headScript()->appendFile("record.js");
@@ -49,7 +50,7 @@ $this->layout()->breadcrumbs .= '<li><a href="' . $this->url('collections-home')
     </ul>
   <? endif; ?>
 
-  <? /* DONT get the toolbar here but below, finc-specific, CK */ ?>
+  <? /* DON'T pull the toolbar in here but below, finc-specific, CK */ ?>
 
     <div class="<?=$tree ? 'col-sm-12' : $this->layoutClass('mainbody')?>">
       <div class="record">
diff --git a/themes/finc/templates/footer.phtml b/themes/finc/templates/footer.phtml
index 0699a7a3e6be54329bbde02a23d84d2053a1fc74..6d220ecba4fb79bb7e2f41effe0244f29273f3e5 100644
--- a/themes/finc/templates/footer.phtml
+++ b/themes/finc/templates/footer.phtml
@@ -1,6 +1,6 @@
 <!-- FOOTER.PHTML begin -->
 <div class="row">
-  <div class="col-sm-4">
+  <div class="col-xs-4">
 
 
     <p><strong><?=$this->transEsc('Search Options')?></strong></p>
@@ -10,7 +10,7 @@
     </ul>
   </div>
 
-  <div class="col-sm-4">
+  <div class="col-xs-4">
 
     <p><strong><?=$this->transEsc('Find More')?></strong></p>
     <ul>
@@ -22,7 +22,7 @@
       <li><a href="<?=$this->url('myresearch-acquisition')?>"><?=$this->transEsc('Suggestions for acquisition')?></a></li>
     </ul>
   </div>
-  <div class="col-sm-4">
+  <div class="col-xs-4">
     <p><strong><?=$this->transEsc('Need Help?')?></strong></p>
     <ul>
       <li><a href="<?=$this->url('help-home')?>?topic=search" data-lightbox class="help-link"><?=$this->transEsc('Search Tips')?></a></li>
@@ -34,7 +34,7 @@
 <? /* finc branding footer */ ?>
 <hr>
 <div class="row powered-by">
-  <div class="col-sm-12">
+  <div class="col-xs-12">
     <span>Powered by</span>
     <a href="https://www.vufind.org" title="vufind.org" target="_blank"><img src="<?=$this->imageLink('vufind_logo.png')?>" alt="powered by VuFind - VuFind Logo" /></a>
     <a href="http://blog.finc.info" title="Blog FinC-Team" target="_blank"><img src="<?=$this->imageLink('finc_logo.png')?>" alt="powered by finc - finc Logo" /></a>
diff --git a/themes/finc/templates/header.phtml b/themes/finc/templates/header.phtml
index 8d873694a628a0f5c5084a5d221e6cccc7bebcae..de2d32d0423e4e58dfd2815978f82359b2565336 100644
--- a/themes/finc/templates/header.phtml
+++ b/themes/finc/templates/header.phtml
@@ -1,11 +1,18 @@
 <!-- HEADER.PHTML begin -->
 <? $account = $this->auth()->getManager(); ?>
-<div class="navbar-header">
-  <? /* moved mobile navigation toggler down below h1 - CK */ ?>
 
-  <? /* This nav element is the sticky element in the header - CK */ ?>
-  <nav class="navbar navbar-fixed-top">
-    <? /* Dont use a div class="container" to wrap as it will add a left and right padding */ ?>
+<? /* This nav element is the sticky element in the header - CK */ ?>
+<nav class="navbar navbar-fixed-top">
+  <div class="container-fluid">
+
+    <? /* This element ONLY holds toggler and navbar-brand - CK */ ?>
+    <div class="navbar-header">
+      <? /* mobile navigation toggler - CK */ ?>
+      <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#header-collapse">
+        <span class="sr-only">Toggle navigation</span>
+        <i class="fa fa-bars" aria-hidden="true"></i>
+      </button>
+
       <h1>
         <a class="navbar-brand lang-<?=$this->layout()->userLang?>" href="<?=$this->url('home')?>">
           <? /* Custom finc header - CK */ ?>
@@ -14,116 +21,111 @@
           <? /* Custom finc header - END */ ?>
         </a>
       </h1>
+    </div>
 
-      <? /* mobile navigation toggler - CK */ ?>
-      <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#header-collapse">
-        <span class="sr-only">Toggle navigation</span>
-        <i class="fa fa-bars" aria-hidden="true"></i>
-      </button>
+    <? if ($this->layout()->searchbox !== false): ?>
+      <? /* remove visible-lg to show on small etc, CK */ ?>
+      <section id="searchslots" class="left">
+        <ul class="navbar-left list-unstyled margin-l-xs">
+          <li>
+            <?=$this->layout()->searchbox?>
+          </li>
+        </ul>
+      </section>
+    <? endif; ?>
+    <? if (!isset($this->layout()->renderingError)): ?>
+      <div class="collapse navbar-collapse right" id="header-collapse">
+        <? /* Right-hand  Nav Section */ ?>
+        <nav>
+          <ul class="nav navbar-nav navbar-right flip">
 
-      <? if ($this->layout()->searchbox !== false): ?>
-        <? /* remove visible-lg to show on small etc, CK */ ?>
-        <section id="searchslots" class="left">
-          <ul class="navbar-left list-unstyled margin-l-xs">
-            <li>
-              <?=$this->layout()->searchbox?>
-            </li>
-          </ul>
-        </section>
-      <? endif; ?>
-      <? if (!isset($this->layout()->renderingError)): ?>
-        <div class="collapse navbar-collapse right" id="header-collapse">
-          <? /* Right-hand  Nav Section */ ?>
-          <nav>
-            <ul class="nav navbar-nav navbar-right flip">
+            <? if ($this->feedback()->tabEnabled()): ?>
+              <li>
+                <a id="feedbackLink" class="btn" data-lightbox href="<?=$this->url('feedback-home')?>">
+                  <i class="fa fa-envelope" aria-hidden="true"></i>
+                  <span class="hidden-sm"><?=$this->transEsc("Feedback")?></span>
+                </a>
+              </li>
+            <? endif; ?>
+            <? $cart = $this->cart();
+            if ($cart->isActive()): ?>
+              <li id="cartSummary">
+                <a id="cartItems" class="btn" data-lightbox title="<?=$this->transEsc('View Book Bag')?>" href="<?=$this->url('cart-home')?>">
+                  <i class="fa fa-clipboard" aria-hidden="true"></i> <strong><?=count($cart->getItems())?></strong>
+                  <span class="hidden-sm"><?=$this->transEsc('items')?><?=$cart->isFull() ? ' (' . $this->transEsc('bookbag_full') . ')' : ''?></span>
+                </a>
+              </li>
+            <? endif; ?>
+            <? if (is_object($account) && $account->loginEnabled()): // hide login/logout if unavailable ?>
+              <li class="logoutOptions<? if (!$account->isLoggedIn()): ?> hidden<? endif ?>">
+                <a class="btn" href="<?=$this->url('myresearch-home', array(), array('query' => array('redirect' => 0)))?>">
+                  <i class="fa fa-home" aria-hidden="true"></i>
+                  <span class="hidden-sm"><?=$this->transEsc("Your Account")?></span>
+                </a>
+              </li>
 
-              <? if ($this->feedback()->tabEnabled()): ?>
-                <li>
-                  <a id="feedbackLink" class="btn" data-lightbox href="<?=$this->url('feedback-home')?>">
-                    <i class="fa fa-envelope" aria-hidden="true"></i>
-                    <span class="hidden-sm"><?=$this->transEsc("Feedback")?></span>
-                  </a>
-                </li>
-              <? endif; ?>
-              <? $cart = $this->cart();
-              if ($cart->isActive()): ?>
-                <li id="cartSummary">
-                  <a id="cartItems" class="btn" data-lightbox title="<?=$this->transEsc('View Book Bag')?>" href="<?=$this->url('cart-home')?>">
-                    <i class="fa fa-clipboard" aria-hidden="true"></i> <strong><?=count($cart->getItems())?></strong>
-                    <span class="hidden-sm"><?=$this->transEsc('items')?><?=$cart->isFull() ? ' (' . $this->transEsc('bookbag_full') . ')' : ''?></span>
-                  </a>
-                </li>
-              <? endif; ?>
-              <? if (is_object($account) && $account->loginEnabled()): // hide login/logout if unavailable ?>
-                <li class="logoutOptions<? if (!$account->isLoggedIn()): ?> hidden<? endif ?>">
-                  <a class="btn" href="<?=$this->url('myresearch-home', array(), array('query' => array('redirect' => 0)))?>">
-                    <i class="fa fa-home" aria-hidden="true"></i>
-                    <span class="hidden-sm"><?=$this->transEsc("Your Account")?></span>
-                  </a>
-                </li>
+              <li class="logoutOptions<? if (!$account->isLoggedIn()): ?> hidden<? endif ?>">
+                <a class="logout btn" href="<?=$this->url('myresearch-logout')?>" title="<?=$this->transEsc("Log Out")?>">
+                  <i class="fa fa-sign-out" aria-hidden="true"></i>
+                  <span class="hidden-sm"><?=$this->transEsc("Log Out")?></span>
+                </a>
+              </li>
 
-                <li class="logoutOptions<? if (!$account->isLoggedIn()): ?> hidden<? endif ?>">
-                  <a class="logout btn" href="<?=$this->url('myresearch-logout')?>" title="<?=$this->transEsc("Log Out")?>">
-                    <i class="fa fa-sign-out" aria-hidden="true"></i>
-                    <span class="hidden-sm"><?=$this->transEsc("Log Out")?></span>
+              <li id="loginOptions"<? if ($account->isLoggedIn()): ?> class="hidden"<? endif ?>>
+                <? if ($account->getSessionInitiator($this->serverUrl($this->url('myresearch-home')))): ?>
+                  <a class="btn" href="<?=$this->url('myresearch-userlogin')?>">
+                    <i class="fa fa-sign-in" aria-hidden="true"></i>
+                    <span class="hidden-sm"><?=$this->transEsc("Institutional Login")?></span>
                   </a>
-                </li>
-
-                <li id="loginOptions"<? if ($account->isLoggedIn()): ?> class="hidden"<? endif ?>>
-                  <? if ($account->getSessionInitiator($this->serverUrl($this->url('myresearch-home')))): ?>
-                    <a class="btn" href="<?=$this->url('myresearch-userlogin')?>">
-                      <i class="fa fa-sign-in" aria-hidden="true"></i>
-                      <span class="hidden-sm"><?=$this->transEsc("Institutional Login")?></span>
-                    </a>
-                  <? else: ?>
-                    <a class="btn" href="<?=$this->url('myresearch-userlogin')?>" data-lightbox>
-                      <i class="fa fa-sign-in" aria-hidden="true"></i>
-                      <span class="hidden-sm"><?=$this->transEsc("Login")?></span>
-                    </a>
-                  <? endif; ?>
-                </li>
-              <? endif; ?>
+                <? else: ?>
+                  <a class="btn" href="<?=$this->url('myresearch-userlogin')?>" data-lightbox>
+                    <i class="fa fa-sign-in" aria-hidden="true"></i>
+                    <span class="hidden-sm"><?=$this->transEsc("Login")?></span>
+                  </a>
+                <? endif; ?>
+              </li>
+            <? endif; ?>
 
-              <? if (isset($this->layout()->themeOptions) && count($this->layout()->themeOptions) > 1): ?>
-                <li class="theme dropdown">
-                  <form method="post" name="themeForm" id="themeForm">
-                    <input type="hidden" name="ui"/>
-                  </form>
-                  <a href="#" class="dropdown-toggle" data-toggle="dropdown"><?=$this->transEsc("Theme")?> <strong class="caret"></strong></a>
+            <? if (isset($this->layout()->themeOptions) && count($this->layout()->themeOptions) > 1): ?>
+              <li class="theme dropdown">
+                <form method="post" name="themeForm" id="themeForm">
+                  <input type="hidden" name="ui"/>
+                </form>
+                <a href="#" class="dropdown-toggle" data-toggle="dropdown"><?=$this->transEsc("Theme")?> <strong class="caret"></strong></a>
 
-                  <ul class="dropdown-menu">
-                    <? foreach ($this->layout()->themeOptions as $current): ?>
-                      <li<?=$current['selected'] ? ' class="active"' : ''?>>
-                        <a href="#" onClick="document.themeForm.ui.value='<?=$this->escapeHtmlAttr($current['name'])?>';document.themeForm.submit()"><?=$this->transEsc($current['desc'])?></a>
-                      </li>
-                    <? endforeach; ?>
-                  </ul>
-                </li>
-              <? endif; ?>
+                <ul class="dropdown-menu">
+                  <? foreach ($this->layout()->themeOptions as $current): ?>
+                    <li<?=$current['selected'] ? ' class="active"' : ''?>>
+                      <a href="#" onClick="document.themeForm.ui.value='<?=$this->escapeHtmlAttr($current['name'])?>';document.themeForm.submit()"><?=$this->transEsc($current['desc'])?></a>
+                    </li>
+                  <? endforeach; ?>
+                </ul>
+              </li>
+            <? endif; ?>
 
-              <? if (isset($this->layout()->allLangs) && count($this->layout()->allLangs) > 1): ?>
-                <li class="language dropdown">
-                  <form method="post" name="langForm" id="langForm">
-                    <input type="hidden" name="mylang"/>
-                  </form>
-                  <a class="btn dropdown-toggle hidden-xs hidden-sm" data-toggle="dropdown" href="#" aria-controls="langmenu" aria-expanded="false"><?=$this->transEsc("Language")?> <strong
-                      class="caret"></strong></a>
+            <? if (isset($this->layout()->allLangs) && count($this->layout()->allLangs) > 1): ?>
+              <li class="language dropdown">
+                <form method="post" name="langForm" id="langForm">
+                  <input type="hidden" name="mylang"/>
+                </form>
+                <a class="btn dropdown-toggle hidden-xs hidden-sm" data-toggle="dropdown" href="#" aria-controls="langmenu" aria-expanded="false"><?=$this->transEsc("Language")?> <strong
+                    class="caret"></strong></a>
 
-                  <ul id="langmenu" class="dropdown-menu">
-                    <? foreach ($this->layout()->allLangs as $langCode => $langName): ?>
-                      <li<?=$this->layout()->userLang == $langCode ? ' class="active"' : ''?>>
-                        <a class="btn" href="#" onClick="document.langForm.mylang.value='<?=$langCode?>';document.langForm.submit()"><?=$this->displayLanguageOption($langName)?></a>
-                      </li>
-                    <? endforeach; ?>
-                  </ul>
-                </li>
-              <? endif; ?>
-            </ul>
-          </nav>
-        </div>
-      <? endif; ?>
+                <ul id="langmenu" class="dropdown-menu">
+                  <? foreach ($this->layout()->allLangs as $langCode => $langName): ?>
+                    <li<?=$this->layout()->userLang == $langCode ? ' class="active"' : ''?>>
+                      <a class="btn" href="#" onClick="document.langForm.mylang.value='<?=$langCode?>';document.langForm.submit()"><?=$this->displayLanguageOption($langName)?></a>
+                    </li>
+                  <? endforeach; ?>
+                </ul>
+              </li>
+            <? endif; ?>
+          </ul>
+        </nav>
+      </div>
+    <? endif; ?>
 
 
-  </nav>
+</nav>
 </div>
-<!-- HEADER.PHTML end -->
+<!-- HEADER.PHTML end -->
\ No newline at end of file
diff --git a/themes/finc/templates/myresearch/bulk-action-buttons.phtml b/themes/finc/templates/myresearch/bulk-action-buttons.phtml
index c59d6050d1737ad6cef859dc2ebcc195143206e4..57f629e265508cfedf5229e03af17884ac0e878e 100644
--- a/themes/finc/templates/myresearch/bulk-action-buttons.phtml
+++ b/themes/finc/templates/myresearch/bulk-action-buttons.phtml
@@ -9,7 +9,7 @@
     <?=$this->transEsc('select_page')?> | <?=$this->transEsc('with_selected')?>:
   </label>
 </div>
-<? /* Keep bulkActionButtons class as it styles the buttons to appear as btn-transparent*/ ?>
+
 <div class="btn-group bulkActionButtons hidden-print">
   <input class="btn btn-transparent" type="submit" name="email" value="<?=$this->transEsc('Email')?>" title="<?=$this->transEsc('email_selected')?>"/>
   <? if ((!is_null($this->list) && $this->list->editAllowed($user)) || is_null($this->list) && $user): ?>
diff --git a/themes/finc/templates/record/emailhold.phtml b/themes/finc/templates/record/emailhold.phtml
index cc9a2e5572857cb04b217c694edda7fd084e547f..18556f62e1fe3dcb7aad1a7dc16ca5c39ee85d61 100644
--- a/themes/finc/templates/record/emailhold.phtml
+++ b/themes/finc/templates/record/emailhold.phtml
@@ -59,7 +59,7 @@
           ?>
           <label class="col-sm-3"><?=$this->transEsc("EmailHold::pick_up_location")?>:</label>
           <div class="col-sm-9">
-            <select name="gatheredDetails[pickUpLocation]" class="auto">
+            <select name="gatheredDetails[pickUpLocation]" class="form-control">
             <? if ($selected === false): ?>
               <option value="" selected="selected">
                 <?=$this->transEsc('EmailHold::select_pickup_location')?>
diff --git a/themes/finc/js/openurl.js b/themes/finc/js/openurl.js
index 578e73d0c24ca466773ef6e2ba6d39334df329e0..cc66d9d92200a940f51dcc0b64b08ee65ac909b1 100644
--- a/themes/finc/js/openurl.js
+++ b/themes/finc/js/openurl.js
@@ -20,21 +20,21 @@ VuFind.register('openurl', function() {
   var embedOpenUrlLinks = function(element) {
     // Extract the OpenURL associated with the clicked element:
     var openUrl = element.children('span.openUrl:first').attr('title');
-  
-    // Hide the controls now that something has been clicked:
+
+    // hidden the controls now that something has been clicked:
     var controls = element.parents('.openUrlControls');
-    controls.removeClass('openUrlEmbed').addClass('hide');
-  
+    controls.removeClass('openUrlEmbed').addClass('hidden');
+
     // Locate the target area for displaying the results:
     var target = controls.next('div.resolver');
-  
+
     // To chose the right resolver we have to get the resolvertype:
     var resolvertype = element.children('span.resolvertype:first').attr('title');
-  
+
     // If the target is already visible, a previous click has populated it;
     // don't waste time doing redundant work.
-    if (target.hasClass('hide')) {
-      _loadResolverLinks(target.removeClass('hide'), openUrl, element.data('search-class-id'), resolvertype);
+    if (target.hasClass('hidden')) {
+      _loadResolverLinks(target.removeClass('hidden'), openUrl, element.data('search-class-id'), resolvertype);
     }
   };
 
@@ -44,7 +44,7 @@ VuFind.register('openurl', function() {
     if (typeof(container) == 'undefined') {
       container = $('body');
     }
-  
+
     // assign action to the openUrlWindow link class
     container.find('a.openUrlWindow').unbind('click').click(function() {
       var params = extractClassParams(this);
@@ -52,13 +52,13 @@ VuFind.register('openurl', function() {
       window.open($(this).attr('href'), 'openurl', settings);
       return false;
     });
-  
+
     // assign action to the openUrlEmbed link class
     container.find('.openUrlEmbed a').unbind('click').click(function() {
       embedOpenUrlLinks($(this));
       return false;
     });
-  
+
     container.find('.openUrlEmbed.openUrlEmbedAutoLoad a').trigger('click');
   };
   return {